pub struct OpenOptions { /* private fields */ }Expand description
Options for opening a file.
This struct provides a builder-style API for configuring how a file
should be opened, similar to std::fs::OpenOptions. The individual
flags are stored in a single bitfield and exposed via is_* accessors.
Implementations
Sourceimpl OpenOptions
impl OpenOptions
Sourceimpl OpenOptions
impl OpenOptions
Sourcepub fn create_new(self, value: bool) -> Self
pub fn create_new(self, value: bool) -> Self
Set the create_new flag.
Sourceimpl OpenOptions
impl OpenOptions
Sourcepub fn is_create_new(&self) -> bool
pub fn is_create_new(&self) -> bool
Returns true if the file must be created new (failing if it exists).
Sourcepub fn is_truncate(&self) -> bool
pub fn is_truncate(&self) -> bool
Returns true if the file will be truncated to zero length on open.
Sourcepub fn is_append(&self) -> bool
pub fn is_append(&self) -> bool
Returns true if writes will be appended to the end of the file.
Sourcepub fn create_write() -> Self
pub fn create_write() -> Self
Create options for creating and writing a new file (truncating if exists).
Sourcepub fn create_new_write() -> Self
pub fn create_new_write() -> Self
Create options for creating a new file for writing (fails if exists).